@@ -21,9 +21,10 @@
 #ifndef EV_PAGE_ACTION_H
 #define EV_PAGE_ACTION_H
 
-#include <gtk/gtkaction.h>
-#include <gtk/gtktreemodel.h>
+#include <gtk/gtk.h>
+
 #include <ev-document.h>
+#include "ev-link.h"
 
 G_BEGIN_DECLS
 
@@ -52,8 +53,6 @@ struct _EvPageActionClass
 
 	void     (* activate_link) (EvPageAction *page_action,
 			            EvLink       *link);
-	gboolean (*activate_label) (EvPageAction *page_action,
-				    const gchar  *label);
 };
 
 GType ev_page_action_get_type     (void);
